.. role:: hidden
    :class: hidden-section


Data Generators (deprecated)
============================

.. currentmodule:: sconce.data_generators


:hidden:`DataGenerator (deprecated)`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: DataGenerator
    :members:

:hidden:`ImageDataGenerator (deprecated)`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: ImageDataGenerator

:hidden:`SingleClassImageDataGenerator (deprecated)`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: SingleClassImageDataGenerator
    :members:
    :show-inheritance:
    :inherited-members:


:hidden:`MultiClassImageDataGenerator (deprecated)`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: MultiClassImageDataGenerator
    :members:
    :show-inheritance:
    :inherited-members:
